# MeshAI SDK

MeshAI SDK is a toolkit for decentralized AI model development, allowing domain teams to select and fine-tune appropriate pre-trained models based on their data, regardless of the data type (text, images, numerical data).

## Installation

You can install the MeshAI SDK from PyPI:

```bash
pip install meshai
